searchData={"items":[{"type":"module","title":"Idiom","doc":"A new take on internationalisation in Elixir.","ref":"Idiom.html"},{"type":"module","title":"Basic usage - Idiom","doc":"Interaction with Idiom happens through `t/3`.\n\n```elixir\n# Set the locale\nIdiom.put_locale(\"en-US\")\n\nt(\"landing.welcome\")\n\n# With natural language key\nt(\"Hello Idiom!\")\n\n# With interpolation\nt(\"Good morning, {{name}}. We hope you are having a great day.\", %{name: \"Tim\"})\n\n# With plural and interpolation\nt(\"You need to buy {{count}} carrots\", count: 1)\n\n# With namespace\nt(\"signup:Create your account\")\nt(\"Create your account\", namespace: \"signup\")\nIdiom.put_namespace(\"signup\")\nt(\"Create your account\")\n\n# With explicit locale\nt(\"Create your account\", to: \"fr\")\n\n# With fallback locale\nt(\"Create your account\", to: \"fr\", fallback: \"en\")\n```","ref":"Idiom.html#module-basic-usage"},{"type":"module","title":"Installation - Idiom","doc":"To start off, add `idiom` to the list of your dependencies:\n```elixir\ndef deps do\n  {:idiom, \"~> 0.1\"},\nend\n```\n\nAdditionally, in order to be able refresh translations in the background, add Idiom's `Supervisor` to your application:\n```elixir\ndef start(_type, _args) do\n  children = [\n    Idiom,\n  ]\n\n  # ...\nend\n```","ref":"Idiom.html#module-installation"},{"type":"module","title":"Configuration - Idiom","doc":"There are a few things around Idiom that you can configure on an application level. The following fence shows all of Idiom's settings and their defaults.\n\n```elixir\nconfig :idiom,\n  default_locale: \"en\",\n  default_fallback: \"en\",\n  default_namespace: \"default\",\n  ota_provider: nil\n```\n\nIn order to configure your OTA provider, please have a look at its module documentation.","ref":"Idiom.html#module-configuration"},{"type":"module","title":"Locales - Idiom","doc":"When calling `t/3`, Idiom looks at the following settings to determine which locale to translate the key to, in order of priority:\n\n1. The explicit `to` option. When you call `t(\"key\", to: \"fr\")`, Idiom will always use `fr` as a locale.\n2. The locale set in the current process. You can call `Idiom.put_locale/1` to set it.\nSince this is just a wrapper around the process dictionary, it needs to be set for each process you are using Idiom in.\n3. The `default_locale` setting. See the [Configuration](#module-configuration) section for more details on how to set it.\n\n#","ref":"Idiom.html#module-locales"},{"type":"module","title":"Resolution hierarchy - Idiom","doc":"> ##","ref":"Idiom.html#module-resolution-hierarchy"},{"type":"module","title":"A note on examples {: .info} - Idiom","doc":">\n> For ease of presentation, whenever an example in this module documentation includes a translation file for context, it will be merged from the multiple\n> files that `Idiom.Source.Local` actually expects. Instead of giving you the contents of all `en/default.json`, `en-US/default.json`, `en-GB/default.json`\n> and others, it will be represented here as one merged file, such as:\n> ```json\n> { \n>   \"en\": {\"default\": { [Contents of what would usually be `en/default.json` ] }},\n>   \"en-US\": {\"default\": { [Contents of what would usually be `en-US/default.json` ] }},\n>   ...\n> }\n> ```\n\nLocale codes can consist of multiple parts. Taking `zh-Hant-HK` as an example, we have the language (`zh` - Chinese), the script (`Hant`, Tradtional) and the\nregion (`HK` - Hong Kong). For different regions, there might only be differences for some specific keys, whereas all other keys share a translation. In\norder to prevent needless repetition in your translation workflow, Idiom will always try to resolve translations in all of language, language and script, and\nlanguage, script and region variants, in order of specifity.\n\nTaking the following file as an example (see also [File format](#module-file-format)):\n```json\n{\n  \"en\": {\n    \"default\": {\n      \"Create your account\": \"Create your account\"\n    }\n  },\n  \"en-US\": {\n    \"default\": {\n      \"Take the elevator\": \"Take the elevator\"\n    }\n  },\n  \"en-GB\": {\n    \"default\": {\n      \"Take the elevator\": \"Take the lift\"\n    }\n  }\n}\n```\nThe `Create your account` message is the same for both American and British English, whereas the key `Take the elevator` has different wording for each.\nWith Idiom's resolution hierarchy, you can use both `en-US` and `en-GB` to refer to the `Create your account` key as well.\n\n```elixir\nt(\"Take the elevator\", to: \"en-US\")\n# -> Take the elevator\nt(\"Take the elevator\", to: \"en-GB\")\n# -> Take the lift\n# Will first try to resolve the key in the `en-US` locale, then, since it does not exist, try `en`.\nt(\"Create your account\", to: \"en-US\")\n# -> Create your account\nt(\"Create your account\", to: \"en-GB\")\n# -> Create your account\n```\n\n#","ref":"Idiom.html#module-a-note-on-examples-info"},{"type":"module","title":"Fallback locales - Idiom","doc":"For when a key might not be available in the set locale, you can set a fallback.  \nA fallback can be either a string or a list of strings. If you set the fallback as a list, Idiom will return the translation of the first locale for which\nthe key is available.\n\nWhen you don't explicitly set a `fallback` for `t/3`, Idiom will try the `default_fallback` (see [Configuration](#module-configuration)).\nWhen a key is available in neither the target **or** any of the fallback language, the key will be returned as-is.\n\n\n```elixir\n# will return the translation for `en`\nt(\"Key that is only available in `en` and `fr`\", to: \"es\", fallback: \"en\")\n# will return the translation for `fr`\nt(\"Key that is only available in `en` and `fr`\", to: \"es\", fallback: [\"fr\", \"en\"])\n# will return the translation for `en`, which is set as `default_fallback`\nt(\"Key that is only available in `en` and `fr`\", to: \"es\")\n# will return \"Key that is not available in any locale\"\nt(\"Key that is not available in any locale\", to: \"es\")\n```","ref":"Idiom.html#module-fallback-locales"},{"type":"module","title":"Namespaces - Idiom","doc":"Idiom allows grouping your keys into namespaces.\n\nWhen calling `t/3`, Idiom looks at the following settings to determine which namespace to resolve the key in, in order of priority:\n1. The `namespace` option, like `t(\"Create your account\", namespace: \"signup\")`\n2. As prefix in the key itself.  \nYou can prefix your key with `{namespace}:` in order to select a namespace, like `t(\"signup:Create your account\")`\n3. The namespace set in the current process. You can call `Idiom.put_namespace/1` to set it.  \nSince this is just a wrapper around the process dictionary, it needs to be set for each process you are using Idiom in.\n4. The `default_namespace` setting. See the [Configuration](#module-configuration) section for more details on how to set it.\n\n#","ref":"Idiom.html#module-namespaces"},{"type":"module","title":"Namespace prefixes and natural language keys - Idiom","doc":"By default, you can use a prefix separated by a colon (`:`) to namespace a key. When using natural language keys, this can cause issues, such as when the key\nitself contains a colon.\n\nConsider the following key: \n```elixir\nt(\"Get started on GitHub: create your account\")\n```\nUsing the colon as a separator, Idiom would try to resolve this as key ` create your account` in the `Get started on GitHub` namespace.\n\nThere are multiple ways to work around this:\n\n1. Explicitly specify the namespace - when a namespace is set this way, the key is left as-is without trying to extract the namespace.\n```elixir\nt(\"Get started on GitHub: create your account\", namespace: \"default\")\n```\n\n2. Set a different namespace separator for the key.\n```elixir\nt(\"Get started on GitHub: create your account\", namespace_separator: \"|\")\n```","ref":"Idiom.html#module-namespace-prefixes-and-natural-language-keys"},{"type":"module","title":"Interpolation - Idiom","doc":"Idiom supports interpolation in messages.  \nInterpolation can be added by adding an interpolation key to the message, enclosing it in `{{}}`. Then, you can bind the key to any string by passing it as\nkey inside the second parameter of `t/3`.\n\nTaking the following file as an example (see also [File format](#module-file-format)):\n```json\n{\n  \"en\": {\n    \"default\": {\n      \"Welcome, {{name}}\": \"Welcome, {{name}}\",\n      \"It is currently {{temperature}} degrees in {{city}}\": \"It is currently {{temperature}} degrees in {{city}}\"\n    }\n  }\n}\n```\n\nThese messages can then be interpolated as such:\n\n```elixir\nt(\"Welcome, {{name}}\", %{name: \"Tim\"})\n# -> Welcome, Tim\nt(\"It is currently {{temperature}} degrees in {{city}}\", %{temperature: \"31\", city: \"Hong Kong\"})\n# -> It is currently 31 degrees in Hong Kong\n```","ref":"Idiom.html#module-interpolation"},{"type":"module","title":"Pluralisation - Idiom","doc":"Idiom supports the following key suffixes for pluralisation:\n\n- `zero`\n- `one`\n- `two`\n- `few`\n- `many`\n- `other`\n\nYour keys, for English, might then look like this:\n\n```json\n{\n  \"carrot_one\": \"{{count}} carrot\"\n  \"carrot_other\": \"{{count}} carrots\"\n}\n```\n\nYou can then pluralise your messages by passing `count` to `t/3`, such as:\n\n```elixir\nt(\"carrot\", count: 1)\n# -> 1 carrot\nt(\"carrot\", count: 2)\n# -> 2 carrot\n```\n\n> #### `{{count}}` and pluralisation {: .info}\n>\n> As you can see in the above example, we are not passing an extra `%{count: x}` binding. This is because the `count` option acts as a magic binding that is\n> automatically available for interpolation.","ref":"Idiom.html#module-pluralisation"},{"type":"module","title":"Sources - Idiom","doc":"#","ref":"Idiom.html#module-sources"},{"type":"module","title":"Local - Idiom","doc":"Idiom loads translations from the file system at startup.  \nPlease see `Idiom.Source.Local` for details on the file structure, file format and things to keep in mind.\n\n#","ref":"Idiom.html#module-local"},{"type":"module","title":"Over the air - Idiom","doc":"Idiom is designed to be extensible with multiple over the air providers. Please see the modules in `Idiom.Source` for the ones built-in, and always feel free\nto extend the ecosystem by creating new ones.","ref":"Idiom.html#module-over-the-air"},{"type":"function","title":"Idiom.get_locale/0","doc":"Returns the locale that will be used by `t/3`.","ref":"Idiom.html#get_locale/0"},{"type":"function","title":"Examples - Idiom.get_locale/0","doc":"```elixir\niex> Idiom.get_locale()\n\"en-US\"\n```","ref":"Idiom.html#get_locale/0-examples"},{"type":"function","title":"Idiom.get_namespace/0","doc":"Returns the namespace that will be used by `t/3`.","ref":"Idiom.html#get_namespace/0"},{"type":"function","title":"Examples - Idiom.get_namespace/0","doc":"```elixir\niex> Idiom.get_namespace()\n\"signup\"\n```","ref":"Idiom.html#get_namespace/0-examples"},{"type":"function","title":"Idiom.put_locale/1","doc":"Sets the locale for the current process.","ref":"Idiom.html#put_locale/1"},{"type":"function","title":"Examples - Idiom.put_locale/1","doc":"```elixir\niex> Idiom.put_locale(\"fr-FR\")\n:ok\n```","ref":"Idiom.html#put_locale/1-examples"},{"type":"function","title":"Idiom.put_namespace/1","doc":"Sets the namespace for the current process.","ref":"Idiom.html#put_namespace/1"},{"type":"function","title":"Examples - Idiom.put_namespace/1","doc":"```elixir\niex> Idiom.put_namespace(\"signup\")\n:ok\n```","ref":"Idiom.html#put_namespace/1-examples"},{"type":"function","title":"Idiom.t/2","doc":"Alias of `t/3` for when you don't need any bindings.","ref":"Idiom.html#t/2"},{"type":"function","title":"Idiom.t/3","doc":"Translates a key into a target language.\n\nThe `translate/2` function takes two arguments:\n- `key`: The specific key for which the translation is required.\n- `opts`: An optional list of options.","ref":"Idiom.html#t/3"},{"type":"function","title":"Target and fallback languages - Idiom.t/3","doc":"For both target and fallback languages, the selected options are based on the following order of priority:\n1. The `:to` and `:fallback` keys in `opts`.\n2. The `:locale` and `:fallback` keys in the current process dictionary.\n3. The application configuration's `:default_locale` and `:default_fallback` keys.\n\nThe language needs to be a single string, whereas the fallback can both be a single string or a list of strings.","ref":"Idiom.html#t/3-target-and-fallback-languages"},{"type":"function","title":"Namespaces - Idiom.t/3","doc":"Keys can be namespaced. ... write stuff here","ref":"Idiom.html#t/3-namespaces"},{"type":"function","title":"Configuration - Idiom.t/3","doc":"Application-wide configuration can be set in `config.exs` like so:\n\n```elixir\nconfig :idiom,\n  default_locale: \"en\",\n  default_fallback: \"fr\"\n  # default_fallback: [\"fr\", \"es\"]\n```","ref":"Idiom.html#t/3-configuration"},{"type":"function","title":"Examples - Idiom.t/3","doc":"iex> translate(\"hello\", to: \"es\")\n    \"hola\"\n\n    # If no `:to` option is provided, it will check the process dictionary:\n    iex> Process.put(:lang, \"fr\")\n    iex> translate(\"hello\")\n    \"bonjour\"\n\n    # If neither `:to` option is provided nor `:lang` is set in the process, it will check the application configuration:\n    # Given `config :idiom, default_lang: \"en\"` is set in the `config.exs` file:\n    iex> translate(\"hello\")\n    \"hello\"\n\n    # If a key does not exist in the target language, it will use the `:fallback` option:\n    iex> translate(\"hello\", to: \"de\", fallback: \"fr\")\n    \"bonjour\"\n\n    # If a key does not exist in the target language or the first fallback language:\n    iex> translate(\"hello\", to: \"de\", fallback: [\"pl\", \"fr\"])\n    \"bonjour\"","ref":"Idiom.html#t/3-examples"},{"type":"type","title":"Idiom.translate_opts/0","doc":"","ref":"Idiom.html#t:translate_opts/0"},{"type":"module","title":"Idiom.Cache","doc":"Cache for translations.\n\nIdiom is flexible in terms of which source translations can be retrieved from. It comes with a few different ones out of the box, and can also be extended\nthrough plugins. `Idiom.Cache` provides utilities to interact with the ETS table that acts as a central storage for translations, both for adding/updating\nkeys and retrieving values.","ref":"Idiom.Cache.html"},{"type":"function","title":"Idiom.Cache.get_translation/4","doc":"Retrieves a translation from the cache.","ref":"Idiom.Cache.html#get_translation/4"},{"type":"function","title":"Examples - Idiom.Cache.get_translation/4","doc":"```elixir\niex> Cache.get_translation(\"de\", \"default\", \"butterfly\")\n\"Schmetterling\"\n```","ref":"Idiom.Cache.html#get_translation/4-examples"},{"type":"function","title":"Idiom.Cache.init/2","doc":"Starts a new cache.\n\nAllows adding initial state by passing it as first parameter.","ref":"Idiom.Cache.html#init/2"},{"type":"function","title":"Examples - Idiom.Cache.init/2","doc":"```elixir\niex> initial_state = %{\n...>  \"en\" => %{\"signup\" => %{\"Create your account\" => \"Create your account\"}}, \n...>  \"de\" => %{\"signup\" => %{\"Create your account\" => \"Erstelle deinen Account\"}}\n...>}\niex> Idiom.Cache.init(initial_state)\n:ok\n\niex> Idiom.Cache.init(%{}, :different_cache_name)\n:ok\n```","ref":"Idiom.Cache.html#init/2-examples"},{"type":"function","title":"Idiom.Cache.insert_keys/2","doc":"Adds a map of keys to the cache.","ref":"Idiom.Cache.html#insert_keys/2"},{"type":"function","title":"Examples - Idiom.Cache.insert_keys/2","doc":"```elixir\niex> Idiom.Cache.insert_keys(%{\n...>  \"en\" => %{\"signup\" => %{\"Create your account\" => \"Create your account\"}}, \n...>  \"de\" => %{\"signup\" => %{\"Create your account\" => \"Erstelle deinen Account\"}}}\n...>)\n:ok\n```","ref":"Idiom.Cache.html#insert_keys/2-examples"},{"type":"module","title":"Idiom.Interpolation","doc":"Functionality for interpolating variables into a message string.","ref":"Idiom.Interpolation.html"},{"type":"function","title":"Idiom.Interpolation.interpolate/2","doc":"Interpolates a message string with a map of bindings.\n\nThe message string can include variables wrapped in `{{}}`. For example, in the string `Hello, {{name}}!`, `{{name}}` is a variable.  \nIf a variable exists in the message string, but not in the bindings, it is converted to a string in-place.","ref":"Idiom.Interpolation.html#interpolate/2"},{"type":"function","title":"Examples - Idiom.Interpolation.interpolate/2","doc":"```elixir\niex> Idiom.Interpolation.interpolate(\"Hello, {{name}}!\", %{name: \"John\"})\n\"Hello, John!\"\n\niex> Idiom.Interpolation.interpolate(\"Hello, {{name}}! It is {{day_of_week}}.\", %{name: \"John\", day_of_week: \"Monday\"})\n\"Hello, John! It is Monday.\"\n\niex> Idiom.Interpolation.interpolate(\"Hello, {{name}}! It is {{day_of_week}}.\", %{name: \"John\"})\n\"Hello, John! It is day_of_week.\"\n```","ref":"Idiom.Interpolation.html#interpolate/2-examples"},{"type":"module","title":"Idiom.Locales","doc":"Utility functions for handling locales.\n\nLocale identifiers consist of a language code, an optional script code, and an optional region code, separated by a hyphen (-).","ref":"Idiom.Locales.html"},{"type":"function","title":"Idiom.Locales.get_hierarchy/2","doc":"Constructs a hierarchical list of locale identifiers from the given locale.\n\nThe `fallback` option allows you to specify a fallback locale that will be added to the end of the hierarchy if it's not already included. By default, no\nfallback language is added.","ref":"Idiom.Locales.html#get_hierarchy/2"},{"type":"function","title":"Examples - Idiom.Locales.get_hierarchy/2","doc":"```elixir\niex> Idiom.Locales.get_hierarchy(\"en-Latn-US\")\n[\"en-Latn-US\", \"en-Latn\", \"en\"]\n\niex> Idiom.Locales.get_hierarchy(\"de-DE\", fallback: \"en\")\n[\"de-DE\", \"de\", \"en\"]\n```","ref":"Idiom.Locales.html#get_hierarchy/2-examples"},{"type":"function","title":"Idiom.Locales.get_language/1","doc":"Extracts the language code from the given locale identifier.","ref":"Idiom.Locales.html#get_language/1"},{"type":"function","title":"Examples - Idiom.Locales.get_language/1","doc":"```elixir\niex> Idiom.Locales.get_language(\"en-Latn-US\")\n\"en\"\n\niex> Idiom.Locales.get_language(\"de-DE\")\n\"de\"\n```","ref":"Idiom.Locales.html#get_language/1-examples"},{"type":"function","title":"Idiom.Locales.get_language_and_script/1","doc":"Extracts the language and script codes from the given locale identifier.\n\nReturns `nil` if the given locale does not have a script code.","ref":"Idiom.Locales.html#get_language_and_script/1"},{"type":"function","title":"Examples - Idiom.Locales.get_language_and_script/1","doc":"```elixir\niex> Idiom.Locales.get_language_and_script(\"en-Latn-US\")\n\"en-Latn\"\n\niex> Idiom.Locales.get_language_and_script(\"de-DE\")\nnil\n```","ref":"Idiom.Locales.html#get_language_and_script/1-examples"},{"type":"module","title":"Idiom.Plural","doc":"Functionality for handling plurals and plural suffixes.\n\nIdiom handles plurals by adding suffixes to keys. These suffixes are as defined by the Unicode CLDR plural rules:\n- `zero`\n- `one`\n- `two`\n- `few`\n- `many`\n- `other`\n\nUsed suffixes differ greatly by language. In order to support them all, and also make this module easier to keep up-to-date, the `PluralPreprocess` module\nparses them and generates ASTs for `cond` expressions. This module reads the definition file at compile time, and generates helper functions for each\nlanguage.","ref":"Idiom.Plural.html"},{"type":"function","title":"Idiom.Plural.get_suffix/2","doc":"Returns the appropriate plural suffix based on a given locale and count.\n\nThe function will determine the correct plural form to use based on the `count` parameter.\nIt supports different types of count values, including binary, float, integer and Decimal types.\n\nWhen the count is `nil`, the function will default to `other`.","ref":"Idiom.Plural.html#get_suffix/2"},{"type":"function","title":"Examples - Idiom.Plural.get_suffix/2","doc":"```elixir\niex> Idiom.Plural.get_suffix(\"en\", 1)\n\"one\"\n\niex> Idiom.Plural.get_suffix(\"en\", 2)\n\"other\"\n\niex> Idiom.Plural.get_suffix(\"ar\", 0)\n\"zero\"\n\niex> Idiom.Plural.get_suffix(\"ar\", \"5\")\n\"few\"\n\niex> Idiom.Plural.get_suffix(\"ar\", Decimal.new(5))\n\"few\"\n```","ref":"Idiom.Plural.html#get_suffix/2-examples"},{"type":"module","title":"Idiom.PluralPreprocess","doc":"Preprocessor for language-specific pluralization rules.\n\nIdiom uses Unicode CLDR plural rules, which they provide for download as a JSON file. This is stored in our `priv` directory.\nThe `Plural` and `PluralPreprocess` modules use these definitions to generate Elixir ASTs representing a `cond` statement for each language, which are then\nused at compile-time to generate functions.\nThis module builds on a lexer and parser inside the `src/` directory to generate the ASTs.","ref":"Idiom.PluralPreprocess.html"},{"type":"function","title":"Idiom.PluralPreprocess.parse_rules/1","doc":"Parses a list of plural rules and converts them into a `:cond` expression, with the clauses sorted by plural suffix.","ref":"Idiom.PluralPreprocess.html#parse_rules/1"},{"type":"function","title":"Examples - Idiom.PluralPreprocess.parse_rules/1","doc":"```elixir\niex> Idiom.PluralPreprocess.parse_rules([{\"pluralRule-count-one\", \"n = 1\"}])\n{:cond, [], [[do: [{:->, [], [[{:==, [], [{:n, [], nil}, 1]}], \"one\"]}]]]}\n```","ref":"Idiom.PluralPreprocess.html#parse_rules/1-examples"},{"type":"module","title":"Idiom.Source.Local","doc":"","ref":"Idiom.Source.Local.html"},{"type":"module","title":"File format - Idiom.Source.Local","doc":"The `json` files expected by `Idiom.Source.Local` are a subset of the [i18next format](https://www.i18next.com/misc/json-format). The following example shows \nall of its features that Idiom currently supports.\n\n```json\n{\n  \"key\": \"value\",\n  \"keyDeep\": {\n    \"inner\": \"value\"\n  },\n  \"keyInterpolate\": \"replace this {{value}}\",\n  \"keyPluralSimple_one\": \"the singular\",\n  \"keyPluralSimple_other\": \"the plural\",\n  \"keyPluralMultipleEgArabic_zero\": \"the plural form 0\",\n  \"keyPluralMultipleEgArabic_one\": \"the plural form 1\",\n  \"keyPluralMultipleEgArabic_two\": \"the plural form 2\",\n  \"keyPluralMultipleEgArabic_few\": \"the plural form 3\",\n  \"keyPluralMultipleEgArabic_many\": \"the plural form 4\",\n  \"keyPluralMultipleEgArabic_other\": \"the plural form 5\",\n}\n```","ref":"Idiom.Source.Local.html#module-file-format"},{"type":"function","title":"Idiom.Source.Local.data/1","doc":"","ref":"Idiom.Source.Local.html#data/1"},{"type":"module","title":"Idiom.Source.PhraseStrings","doc":"","ref":"Idiom.Source.PhraseStrings.html"},{"type":"function","title":"Idiom.Source.PhraseStrings.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Idiom.Source.PhraseStrings.html#child_spec/1"},{"type":"function","title":"Idiom.Source.PhraseStrings.start_link/1","doc":"","ref":"Idiom.Source.PhraseStrings.html#start_link/1"},{"type":"module","title":"Idiom.Source.PhraseStrings.OTA","doc":"","ref":"Idiom.Source.PhraseStrings.OTA.html"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.delete/3","doc":"Perform a DELETE request.\n\nSee `request/1` or `request/2` for options definition.\n\n    delete(\"/users\")\n    delete(\"/users\", query: [scope: \"admin\"])\n    delete(client, \"/users\")\n    delete(client, \"/users\", query: [scope: \"admin\"])\n    delete(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#delete/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.delete!/3","doc":"Perform a DELETE request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    delete!(\"/users\")\n    delete!(\"/users\", query: [scope: \"admin\"])\n    delete!(client, \"/users\")\n    delete!(client, \"/users\", query: [scope: \"admin\"])\n    delete!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#delete!/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.get/3","doc":"Perform a GET request.\n\nSee `request/1` or `request/2` for options definition.\n\n    get(\"/users\")\n    get(\"/users\", query: [scope: \"admin\"])\n    get(client, \"/users\")\n    get(client, \"/users\", query: [scope: \"admin\"])\n    get(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#get/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.get!/3","doc":"Perform a GET request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    get!(\"/users\")\n    get!(\"/users\", query: [scope: \"admin\"])\n    get!(client, \"/users\")\n    get!(client, \"/users\", query: [scope: \"admin\"])\n    get!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#get!/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.get_strings/1","doc":"","ref":"Idiom.Source.PhraseStrings.OTA.html#get_strings/1"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.head/3","doc":"Perform a HEAD request.\n\nSee `request/1` or `request/2` for options definition.\n\n    head(\"/users\")\n    head(\"/users\", query: [scope: \"admin\"])\n    head(client, \"/users\")\n    head(client, \"/users\", query: [scope: \"admin\"])\n    head(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#head/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.head!/3","doc":"Perform a HEAD request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    head!(\"/users\")\n    head!(\"/users\", query: [scope: \"admin\"])\n    head!(client, \"/users\")\n    head!(client, \"/users\", query: [scope: \"admin\"])\n    head!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#head!/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.options/3","doc":"Perform a OPTIONS request.\n\nSee `request/1` or `request/2` for options definition.\n\n    options(\"/users\")\n    options(\"/users\", query: [scope: \"admin\"])\n    options(client, \"/users\")\n    options(client, \"/users\", query: [scope: \"admin\"])\n    options(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#options/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.options!/3","doc":"Perform a OPTIONS request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    options!(\"/users\")\n    options!(\"/users\", query: [scope: \"admin\"])\n    options!(client, \"/users\")\n    options!(client, \"/users\", query: [scope: \"admin\"])\n    options!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#options!/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.patch/4","doc":"Perform a PATCH request.\n\nSee `request/1` or `request/2` for options definition.\n\n    patch(\"/users\", %{name: \"Jon\"})\n    patch(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    patch(client, \"/users\", %{name: \"Jon\"})\n    patch(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.OTA.html#patch/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.patch!/4","doc":"Perform a PATCH request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    patch!(\"/users\", %{name: \"Jon\"})\n    patch!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    patch!(client, \"/users\", %{name: \"Jon\"})\n    patch!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.OTA.html#patch!/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.post/4","doc":"Perform a POST request.\n\nSee `request/1` or `request/2` for options definition.\n\n    post(\"/users\", %{name: \"Jon\"})\n    post(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    post(client, \"/users\", %{name: \"Jon\"})\n    post(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.OTA.html#post/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.post!/4","doc":"Perform a POST request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    post!(\"/users\", %{name: \"Jon\"})\n    post!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    post!(client, \"/users\", %{name: \"Jon\"})\n    post!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.OTA.html#post!/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.put/4","doc":"Perform a PUT request.\n\nSee `request/1` or `request/2` for options definition.\n\n    put(\"/users\", %{name: \"Jon\"})\n    put(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    put(client, \"/users\", %{name: \"Jon\"})\n    put(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.OTA.html#put/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.put!/4","doc":"Perform a PUT request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    put!(\"/users\", %{name: \"Jon\"})\n    put!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    put!(client, \"/users\", %{name: \"Jon\"})\n    put!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.OTA.html#put!/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.request/2","doc":"Perform a request.","ref":"Idiom.Source.PhraseStrings.OTA.html#request/2"},{"type":"function","title":"Options - Idiom.Source.PhraseStrings.OTA.request/2","doc":"- `:method` - the request method, one of [`:head`, `:get`, `:delete`, `:trace`, `:options`, `:post`, `:put`, `:patch`]\n- `:url` - either full url e.g. \"http://example.com/some/path\" or just \"/some/path\" if using `Tesla.Middleware.BaseUrl`\n- `:query` - a keyword list of query params, e.g. `[page: 1, per_page: 100]`\n- `:headers` - a keyworld list of headers, e.g. `[{\"content-type\", \"text/plain\"}]`\n- `:body` - depends on used middleware:\n    - by default it can be a binary\n    - if using e.g. JSON encoding middleware it can be a nested map\n    - if adapter supports it it can be a Stream with any of the above\n- `:opts` - custom, per-request middleware or adapter options","ref":"Idiom.Source.PhraseStrings.OTA.html#request/2-options"},{"type":"function","title":"Examples - Idiom.Source.PhraseStrings.OTA.request/2","doc":"ExampleApi.request(method: :get, url: \"/users/path\")\n\n    # use shortcut methods\n    ExampleApi.get(\"/users/1\")\n    ExampleApi.post(client, \"/users\", %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#request/2-examples"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.request!/2","doc":"Perform request and raise in case of error.\n\nThis is similar to `request/2` behaviour from Tesla 0.x\n\nSee `request/2` for list of available options.","ref":"Idiom.Source.PhraseStrings.OTA.html#request!/2"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.trace/3","doc":"Perform a TRACE request.\n\nSee `request/1` or `request/2` for options definition.\n\n    trace(\"/users\")\n    trace(\"/users\", query: [scope: \"admin\"])\n    trace(client, \"/users\")\n    trace(client, \"/users\", query: [scope: \"admin\"])\n    trace(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#trace/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.OTA.trace!/3","doc":"Perform a TRACE request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    trace!(\"/users\")\n    trace!(\"/users\", query: [scope: \"admin\"])\n    trace!(client, \"/users\")\n    trace!(client, \"/users\", query: [scope: \"admin\"])\n    trace!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.OTA.html#trace!/3"},{"type":"type","title":"Idiom.Source.PhraseStrings.OTA.option/0","doc":"Options that may be passed to a request function. See `request/2` for detailed descriptions.","ref":"Idiom.Source.PhraseStrings.OTA.html#t:option/0"},{"type":"module","title":"Idiom.Source.PhraseStrings.Strings","doc":"","ref":"Idiom.Source.PhraseStrings.Strings.html"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.delete/3","doc":"Perform a DELETE request.\n\nSee `request/1` or `request/2` for options definition.\n\n    delete(\"/users\")\n    delete(\"/users\", query: [scope: \"admin\"])\n    delete(client, \"/users\")\n    delete(client, \"/users\", query: [scope: \"admin\"])\n    delete(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#delete/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.delete!/3","doc":"Perform a DELETE request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    delete!(\"/users\")\n    delete!(\"/users\", query: [scope: \"admin\"])\n    delete!(client, \"/users\")\n    delete!(client, \"/users\", query: [scope: \"admin\"])\n    delete!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#delete!/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.get/3","doc":"Perform a GET request.\n\nSee `request/1` or `request/2` for options definition.\n\n    get(\"/users\")\n    get(\"/users\", query: [scope: \"admin\"])\n    get(client, \"/users\")\n    get(client, \"/users\", query: [scope: \"admin\"])\n    get(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#get/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.get!/3","doc":"Perform a GET request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    get!(\"/users\")\n    get!(\"/users\", query: [scope: \"admin\"])\n    get!(client, \"/users\")\n    get!(client, \"/users\", query: [scope: \"admin\"])\n    get!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#get!/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.head/3","doc":"Perform a HEAD request.\n\nSee `request/1` or `request/2` for options definition.\n\n    head(\"/users\")\n    head(\"/users\", query: [scope: \"admin\"])\n    head(client, \"/users\")\n    head(client, \"/users\", query: [scope: \"admin\"])\n    head(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#head/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.head!/3","doc":"Perform a HEAD request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    head!(\"/users\")\n    head!(\"/users\", query: [scope: \"admin\"])\n    head!(client, \"/users\")\n    head!(client, \"/users\", query: [scope: \"admin\"])\n    head!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#head!/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.list_available_languages/0","doc":"","ref":"Idiom.Source.PhraseStrings.Strings.html#list_available_languages/0"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.options/3","doc":"Perform a OPTIONS request.\n\nSee `request/1` or `request/2` for options definition.\n\n    options(\"/users\")\n    options(\"/users\", query: [scope: \"admin\"])\n    options(client, \"/users\")\n    options(client, \"/users\", query: [scope: \"admin\"])\n    options(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#options/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.options!/3","doc":"Perform a OPTIONS request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    options!(\"/users\")\n    options!(\"/users\", query: [scope: \"admin\"])\n    options!(client, \"/users\")\n    options!(client, \"/users\", query: [scope: \"admin\"])\n    options!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#options!/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.patch/4","doc":"Perform a PATCH request.\n\nSee `request/1` or `request/2` for options definition.\n\n    patch(\"/users\", %{name: \"Jon\"})\n    patch(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    patch(client, \"/users\", %{name: \"Jon\"})\n    patch(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.Strings.html#patch/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.patch!/4","doc":"Perform a PATCH request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    patch!(\"/users\", %{name: \"Jon\"})\n    patch!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    patch!(client, \"/users\", %{name: \"Jon\"})\n    patch!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.Strings.html#patch!/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.post/4","doc":"Perform a POST request.\n\nSee `request/1` or `request/2` for options definition.\n\n    post(\"/users\", %{name: \"Jon\"})\n    post(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    post(client, \"/users\", %{name: \"Jon\"})\n    post(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.Strings.html#post/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.post!/4","doc":"Perform a POST request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    post!(\"/users\", %{name: \"Jon\"})\n    post!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    post!(client, \"/users\", %{name: \"Jon\"})\n    post!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.Strings.html#post!/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.put/4","doc":"Perform a PUT request.\n\nSee `request/1` or `request/2` for options definition.\n\n    put(\"/users\", %{name: \"Jon\"})\n    put(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    put(client, \"/users\", %{name: \"Jon\"})\n    put(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.Strings.html#put/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.put!/4","doc":"Perform a PUT request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    put!(\"/users\", %{name: \"Jon\"})\n    put!(\"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])\n    put!(client, \"/users\", %{name: \"Jon\"})\n    put!(client, \"/users\", %{name: \"Jon\"}, query: [scope: \"admin\"])","ref":"Idiom.Source.PhraseStrings.Strings.html#put!/4"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.request/2","doc":"Perform a request.","ref":"Idiom.Source.PhraseStrings.Strings.html#request/2"},{"type":"function","title":"Options - Idiom.Source.PhraseStrings.Strings.request/2","doc":"- `:method` - the request method, one of [`:head`, `:get`, `:delete`, `:trace`, `:options`, `:post`, `:put`, `:patch`]\n- `:url` - either full url e.g. \"http://example.com/some/path\" or just \"/some/path\" if using `Tesla.Middleware.BaseUrl`\n- `:query` - a keyword list of query params, e.g. `[page: 1, per_page: 100]`\n- `:headers` - a keyworld list of headers, e.g. `[{\"content-type\", \"text/plain\"}]`\n- `:body` - depends on used middleware:\n    - by default it can be a binary\n    - if using e.g. JSON encoding middleware it can be a nested map\n    - if adapter supports it it can be a Stream with any of the above\n- `:opts` - custom, per-request middleware or adapter options","ref":"Idiom.Source.PhraseStrings.Strings.html#request/2-options"},{"type":"function","title":"Examples - Idiom.Source.PhraseStrings.Strings.request/2","doc":"ExampleApi.request(method: :get, url: \"/users/path\")\n\n    # use shortcut methods\n    ExampleApi.get(\"/users/1\")\n    ExampleApi.post(client, \"/users\", %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#request/2-examples"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.request!/2","doc":"Perform request and raise in case of error.\n\nThis is similar to `request/2` behaviour from Tesla 0.x\n\nSee `request/2` for list of available options.","ref":"Idiom.Source.PhraseStrings.Strings.html#request!/2"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.trace/3","doc":"Perform a TRACE request.\n\nSee `request/1` or `request/2` for options definition.\n\n    trace(\"/users\")\n    trace(\"/users\", query: [scope: \"admin\"])\n    trace(client, \"/users\")\n    trace(client, \"/users\", query: [scope: \"admin\"])\n    trace(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#trace/3"},{"type":"function","title":"Idiom.Source.PhraseStrings.Strings.trace!/3","doc":"Perform a TRACE request.\n\nSee `request!/1` or `request!/2` for options definition.\n\n    trace!(\"/users\")\n    trace!(\"/users\", query: [scope: \"admin\"])\n    trace!(client, \"/users\")\n    trace!(client, \"/users\", query: [scope: \"admin\"])\n    trace!(client, \"/users\", body: %{name: \"Jon\"})","ref":"Idiom.Source.PhraseStrings.Strings.html#trace!/3"},{"type":"type","title":"Idiom.Source.PhraseStrings.Strings.option/0","doc":"Options that may be passed to a request function. See `request/2` for detailed descriptions.","ref":"Idiom.Source.PhraseStrings.Strings.html#t:option/0"},{"type":"module","title":"Idiom.Supervisor","doc":"","ref":"Idiom.Supervisor.html"},{"type":"function","title":"Idiom.Supervisor.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Idiom.Supervisor.html#child_spec/1"},{"type":"function","title":"Idiom.Supervisor.start_link/1","doc":"","ref":"Idiom.Supervisor.html#start_link/1"}],"content_type":"text/markdown"}